"""
====================================

* **Filename**:          __init__.py
* **Author**:            Frank Myhre
* **Description**:       Initialization function/imports.

====================================
"""
from .analysis_object import AnalysisObject
from . import extraction
from . import utils
